==> haskell-happstack-server-7.9.3-19.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.3
visibility:           public
id:                   happstack-server-7.9.3-4miTUrsWG2oIMF2AapJj4E
key:                  happstack-server-7.9.3-4miTUrsWG2oIMF2AapJj4E
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  544effb2201397755ec7ffec9540f5e9
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.3-4miTUrsWG2oIMF2AapJj4E
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    filepath-1.4.300.1 hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV
    html-1.0.1.2-yrvyqtjCXbBHvzYDYrrGC
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS parsec-3.1.16.1
    process-1.6.19.0 sendfile-0.7.11.6-KfZlyB5BRlfIdSHR1qPbya
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt
    system-filepath-0.4.14.1-DPifgQZi1apEQ51HShU6I3 text-2.0.2
    threads-0.5.1.8-KPnnJXhKanG17MR3Y220IW time-1.12.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-2.8.4.0 utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    xhtml-3000.2.2.1 zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-happstack-server-7.9.3-20-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.3
visibility:           public
id:                   happstack-server-7.9.3-3zzuzE4wnty2Ke4haceqjA
key:                  happstack-server-7.9.3-3zzuzE4wnty2Ke4haceqjA
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  dc2dc2394768cdf7a73ae130eda10437
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.3-3zzuzE4wnty2Ke4haceqjA
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    filepath-1.4.300.1 hslogger-1.3.2.0-1NkMetVZZQxCHjmQHJSTJK
    html-1.0.1.2-yrvyqtjCXbBHvzYDYrrGC
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI parsec-3.1.16.1
    process-1.6.19.0 sendfile-0.7.11.6-CH2NSRYQFHK5cBQhDsLjf2
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp
    system-filepath-0.4.14.1-HuIxoRxmfFQmMHeAd2Im text-2.0.2
    threads-0.5.1.8-8ibJ4YUzdSsF27216TJGAU time-1.12.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-2.8.4.0 utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xhtml-3000.2.2.1 zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
